@@ -694,7 +694,10 @@ wrapSpatRaster <- function(obj, cachePath, ...) {
   obj <- asPath(fnsMulti)
 
   relToWhere <- relativeToWhat(obj, cachePath, ...)
-  absBase <- absoluteBase(names(relToWhere), cachePath, ...)
+  # if ("" %in% names(relToWhere)) {
+  #   # absBase <- browser()
+  # }
+  # absBase <- absoluteBase(names(relToWhere), cachePath, ...)
   relPath <- unname(unlist(relToWhere))
   relName <- file.path(relPath, basename2(obj))
 
@@ -729,7 +732,22 @@ unwrapSpatRaster <- function(obj, cachePath, ...) {
   if (isTRUE(any(nchar(fns) > 0))) {
     tags <- attr(obj, "tags")
     if (!is.null(tags)) {
-      newFiles <- remapFilenames(tags, cachePath, ...)
+      if (!is.null(cachePath)) {
+        filenameInCache <- CacheStoredFile(cachePath,
+                                           # cacheId = tools::file_path_sans_ext(basename(obj)),
+                                           obj = obj
+        )
+        feObjs <- file.exists(obj)
+        if (any(feObjs))
+          unlink(obj[feObjs])
+        # fnToLoad <- fns
+        newFiles <- remapFilenames(fns, tags, cachePath, ...)
+        fromFiles <- unlist(filenameInCache)
+      } else {
+        newFiles <- remapFilenames(tags = tags, cachePath = cachePath, ...)
+        fromFiles <- unlist(fns) # fnToLoad <- newFiles$newName
+      }
+      hardLinkOrCopy(fromFiles, newFiles$newName, verbose = 0)
       # tags <- parseTags(tags)
       # origRelName <- extractFromCache(tags, tagOrigRelName)
       # origFilename <- extractFromCache(tags, tagOrigFilename) # tv[tk == tagOrigFilename]
@@ -751,18 +769,20 @@ unwrapSpatRaster <- function(obj, cachePath, ...) {
 
       # whFiles <- newFiles$newName[match(basename(extractFromCache(tags, tagFilesToLoad)), origFilename)]
 
-      if (!is.null(cachePath)) {
-        filenameInCache <- CacheStoredFile(cachePath,
-                                           # cacheId = tools::file_path_sans_ext(basename(obj)),
-                                           obj = obj
-        )
-        feObjs <- file.exists(obj)
-        if (any(feObjs))
-          unlink(obj[feObjs])
-        hardLinkOrCopy(unlist(filenameInCache), newFiles$newName, verbose = 0)
-      } else {
-        hardLinkOrCopy(unlist(fns), newFiles$newName, verbose = 0)
-      }
+      # if (!is.null(cachePath)) {
+      #   filenameInCache <- CacheStoredFile(cachePath,
+      #                                      # cacheId = tools::file_path_sans_ext(basename(obj)),
+      #                                      obj = obj
+      #   )
+      #   feObjs <- file.exists(obj)
+      #   if (any(feObjs))
+      #     unlink(obj[feObjs])
+      #   fnToLoad <- fns
+      #   hardLinkOrCopy(unlist(filenameInCache), fns, verbose = 0)
+      # } else {
+      #   fnToLoad <- newFiles$newName
+      #   hardLinkOrCopy(unlist(fns), newFiles$newName, verbose = 0)
+      # }
 
       obj <- eval(parse(text = extractFromCache(newFiles$tagsParsed, "loadFun")))(newFiles$whFiles)
       possNames <- strsplit(extractFromCache(newFiles$tagsParsed, "layerNames"), split = layerNamesDelimiter)[[1]]
@@ -782,8 +802,6 @@ unwrapSpatRaster <- function(obj, cachePath, ...) {
   obj
 }
 
-
-
 #' @export
 #' @param cacheId Used strictly for messaging. This should be the cacheId of the object being recovered.
 #' @rdname dotWrap
@@ -862,6 +880,7 @@ unwrapRaster <- function(obj, cachePath, cacheId) {
   obj <- .setSubAttrInList(obj, ".Cache", "newCache", FALSE)
   obj
 }
+
 parseTags <- function(tags) {
   out <- strsplit(tags, ":")
   tags2 <- lapply(out, function(x) x[[1]])
@@ -897,16 +916,22 @@ relativeToWhat <- function(file, cachePath, ...) {
   }
   if (isFALSE(foundAbs)) {
     for (nams in names(possRelPaths)) {
-      poss <- fs::path_common(c(file, possRelPaths[nams]))
-      if (!identical(poss, possRelPaths[nams])) {
-        rel <- makeRelative(possRelPaths[nams], poss)
-        relWithDots <- rep("..", length(strsplit(rel, "/|\\\\")[[1]]))
-        poss <- paste(relWithDots, collapse = "/")
-        out <- poss
-        out <- list(out)
-        names(out) <- nams
-        foundAbs <- TRUE
-        break
+      out <- dirname(file)
+      names(out) <- ""
+      if (FALSE) { # this is for rebuilding relative against
+      # poss <- fs::path_common(c(file, possRelPaths[nams]))
+      # if (!identical(poss, possRelPaths[nams])) {
+      #   fileRel <- makeRelative(file, poss)
+      #   rel <- makeRelative(possRelPaths[nams], poss)
+      #   relWithDots <- rep("..", length(strsplit(rel, "/|\\\\")[[1]]))
+      #   poss <- file.path(paste(relWithDots, collapse = "/"), dirname(fileRel))
+      #   out <- poss
+      #   out <- list(out)
+      #   names(out) <- nams
+      #   foundAbs <- TRUE
+      #   break
+      # }
+      # names(out) <- nams
       }
     }
   }
@@ -917,7 +942,7 @@ relativeToWhat <- function(file, cachePath, ...) {
 absoluteBase <- function(relToWhere, cachePath, ...) {
   if (identical(relToWhere, "cachePath") && !is.null(cachePath)) {
     ab <- cachePath
-  } else if(identical(relToWhere, "getwd")) {
+  } else if (identical(relToWhere, "getwd")) {
     ab <- getwd()
   } else {
     possRelPaths <- modifyListPaths(cachePath, ...)
@@ -967,26 +992,30 @@ tagsSpatRaster <- function(obj = NULL, relToWhere = NULL, relName = NULL, cls =
   )
 }
 
-remapFilenames <- function(tags, cachePath, ...) {
+remapFilenames <- function(obj, tags, cachePath, ...) {
   tags <- parseTags(tags)
-  origRelName <- extractFromCache(tags, tagOrigRelName)
   origFilename <- extractFromCache(tags, tagOrigFilename) # tv[tk == tagOrigFilename]
-  relToWhere <- extractFromCache(tags, "relToWhere")
-  possRelPaths <- modifyListPaths(cachePath, ...)
-  if (relToWhere %in% names(possRelPaths)) {
-    absBase <- absoluteBase(relToWhere, cachePath, ...)
-  } else {
-    absBase <- possRelPaths[[1]]
-    isOutside <- grepl(grepStartsTwoDots, origRelName)
-    if (any(isOutside)) {
-      # means the relative path is "outside" of something ... strip all ".." if relToWhere doesn't exist
-      while(any(grepl(grepStartsTwoDots, origRelName))) {
-        origRelName <- gsub(paste0(grepStartsTwoDots, "|(\\\\|/)"), "", origRelName)
+  if (missing(obj)) {
+    origRelName <- extractFromCache(tags, tagOrigRelName)
+    relToWhere <- extractFromCache(tags, "relToWhere")
+    possRelPaths <- modifyListPaths(cachePath, ...)
+    if (relToWhere %in% names(possRelPaths)) {
+      absBase <- absoluteBase(relToWhere, cachePath, ...)
+    } else {
+      absBase <- possRelPaths[[1]]
+      isOutside <- grepl(grepStartsTwoDots, origRelName)
+      if (any(isOutside)) {
+        # means the relative path is "outside" of something ... strip all ".." if relToWhere doesn't exist
+        while(any(grepl(grepStartsTwoDots, origRelName))) {
+          origRelName <- gsub(paste0(grepStartsTwoDots, "|(\\\\|/)"), "", origRelName)
+        }
       }
     }
+    newName <- file.path(absBase, origRelName)
+  } else {
+    newName <- obj
   }
 
-  newName <- file.path(absBase, origRelName)
   whFiles <- newName[match(basename(extractFromCache(tags, tagFilesToLoad)), origFilename)]
   list(newName = newName, whFiles = whFiles, tagsParsed = tags)
 }
